#!/bin/bash

##############################################################################
#
# SCRIPT:       grass7.install.sh
#
# AUTHORS:      Matthias Benedikt, Jan-Thomas Fischer,
#               Andreas Huber, Martin Mergili
#
# PURPOSE:      Installation script for GRASS 7 (dev package), R
#               and R packages, and pillow on Ubuntu 18.04 
#
# COPYRIGHT:    (c) 2010 - 2020 by the authors
#               (c) 2010 - 2020 by the BOKU University, Vienna
#               (c) 2015 - 2020 by the University of Vienna
#               (c) 2016 - 2020 by the BFW, Innsbruck
#
# VERSION:      20200402 (2 April 2020)
#
#               This program is free software under the GNU General Public
#               License (>=v2).
#
##############################################################################

#Making sure that Python 3 is used
sudo apt install python3-pip -y
echo "alias python=python3" >> ~/.bash_aliases
source ~/.bash_aliases

#Selecting suitable repository
sudo add-apt-repository ppa:ubuntugis/ubuntugis-unstable -y
sudo apt update

#Installing necessary additional packages
sudo apt install libgeos-dev -y
sudo apt install libproj-dev proj-data proj-bin -y
sudo apt install libgdal-dev python-gdal gdal-bin -y

#Installing GRASS GIS (dev package)
sudo apt update
sudo apt install grass-dev grass-doc grass-gui -y

#Installing pillow
sudo apt install python-pip
python3 -m pip install --upgrade pillow

#Installing R statistical software
sudo apt-key adv --keyserver keyserver.ubuntu.com --recv-keys E298A3A825C0D65DFD57CBB651716619E084DAB9
sudo add-apt-repository 'deb https://cloud.r-project.org/bin/linux/ubuntu bionic-cran35/'
sudo apt update
sudo apt install r-base r-base-core -y

#Installing necessary additional R packages
echo 'dir.create(Sys.getenv("R_LIBS_USER"), showWarnings = FALSE, recursive = TRUE)' > install.library.R
#echo 'install.packages(c("stats","foreign","sp","rgeos","rgdal","raster","maptools","ROCR","fmsb"), Sys.getenv("R_LIBS_USER"), repos = "http://cran.case.edu" )' > install.packages.R
echo 'install.packages(c("sp","rgeos","rgdal","raster","maptools","ROCR","fmsb"), Sys.getenv("R_LIBS_USER"), repos = "http://cran.case.edu" )' > install.packages.R
sudo R CMD BATCH install.library.R
sudo R CMD BATCH install.packages.R

#Terminating sudo mode
sudo -k
clear
